package com.dafreitag.app.states;

import com.dafreitag.app.machine.AppState;
import com.dafreitag.app.machine.AppMachine;
import javafx.application.Application;
import javafx.geometry.Insets;
import javafx.geometry.Pos;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.effect.DropShadow;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.HBox;
import javafx.scene.layout.VBox;
import javafx.scene.paint.Color;
import javafx.scene.text.Font;
import javafx.scene.text.FontWeight;
import javafx.scene.text.Text;
import javafx.stage.Stage;

public class AppInformationState extends Application implements AppState {
    AppMachine appMachine;

    public AppInformationState(AppMachine appMachine) {
        this.appMachine = appMachine;
    }
	
    @Override // Override the start method in the Application class
    public void start(Stage stage) {
    	BorderPane aroot = new BorderPane();  
        aroot.setStyle("-fx-background-color: lightGreen");

        aroot.setTop(getTop(stage));
        aroot.setCenter(getCenter(stage));
        aroot.setBottom(getBottom(stage));
        
        int height = 500;
        int width  = 600;

        Scene scene = new Scene(aroot, width, height);    
        
        stage.setTitle("By David A. Freitag - Version 1.0");
        
        stage.setScene(scene);
        scene.getStylesheets().add(AppInformationState.class.getResource("application.css").toExternalForm());
        stage.show();   
    }
  	
    private VBox getTop(Stage stage) {
        VBox vbox = new VBox(10);
        vbox.setPadding(new Insets(20, 0, 0, 0));
        vbox.setAlignment(Pos.CENTER);

        Label blankLineT1 = new Label("Information State");
        blankLineT1.setFont(Font.font("Helvetica", FontWeight.BOLD, 18));
        vbox.getChildren().addAll( blankLineT1);

        return vbox;
    }
    
    private VBox getCenter(Stage stage) {
    	VBox vbox = new VBox(10);
    	vbox.setPadding(new Insets(0, 0, 0, 0));
    	vbox.setAlignment(Pos.CENTER);

    	Label blankLine1 = new Label(" ");
    	Label blankLine2 = new Label(" ");
   	 	
    	//----------------------------------------------------------------------
    	DropShadow ds = new DropShadow();
    	ds.setOffsetY(3.0f);
    	ds.setColor(Color.color(0.4f, 0.4f, 0.4f));
    	
    	Text ee = new Text();
    	ee.setEffect(ds);
    	ee.setCache(true);
    	ee.setX(10.0f);
    	ee.setY(270.0f);
    	ee.setFill(Color.DARKBLUE);
    	
  	ee.setText("Provided by: David A. Freitag");
    	ee.setFont(Font.font(null, FontWeight.NORMAL, 22));
    	
    	vbox.getChildren().addAll(ee, blankLine1);
    	
    	//----------------------------------------------------------------------
        VBox vboxText = new VBox(0);
        vboxText.setAlignment(Pos.CENTER);
        
        Label labelText = new Label("The code for this game demonstrates the use of "
            + "nested State Patterns. "
            + "\n"
            + "Refer to the book \"Head First Design Patterns\" for more patterns."
            + "\n\n  ---> App Machine"
            + "\n     ---> Information State"
            + "\n\nReturn goes back to the Title Screen State under the App Machine"
            );

        labelText.setFont(Font.font("Helvetica", FontWeight.NORMAL, 18));
        
        vboxText.getChildren().addAll(labelText);
        vbox.getChildren().addAll(vboxText);
  
        return vbox;
    }
 
    private HBox getBottom(Stage stage) {
        HBox hbox = new HBox(10);
        hbox.setPadding(new Insets(30, 10, 30, 10));
        hbox.setAlignment(Pos.CENTER);
        
        Button btReturn = new Button("   Return   ");
        hbox.getChildren().add(btReturn);

        btReturn.setOnMouseClicked(e -> {
            displayTitleScreen(stage);
        });

        return hbox;
    }
  	
    public void displayTitleScreen(Stage stage) {
            appMachine.setState(appMachine.getAppSplashState()); 
            appMachine.start(stage);
    }

    public void displayInformationScreen(Stage stage) {
            System.out.println("Already in the Copyright Screen");
    }

    public void displayGameScreen(Stage stage) {
            appMachine.setState(appMachine.getAppGameState()); 
            appMachine.start(stage);
    }
}