package com.dafreitag.app.states;

import com.dafreitag.app.machine.AppState;
import com.dafreitag.app.machine.AppMachine;
import javafx.application.Application;
import javafx.geometry.Insets;
import javafx.geometry.Pos;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.effect.DropShadow;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.HBox;
import javafx.scene.layout.VBox;
import javafx.scene.paint.Color;
import javafx.scene.text.Font;
import javafx.scene.text.FontWeight;
import javafx.scene.text.Text;
import javafx.stage.Stage;

public class AppTitleScreenState extends Application implements AppState {
    AppMachine appMachine;

    public AppTitleScreenState(AppMachine appMachine) {
        this.appMachine = appMachine;
    }

    @Override // Override the start method in the Application class
    public void start(Stage stage) {
        BorderPane aroot = new BorderPane();   
        aroot.setStyle("-fx-background-color: lightGreen"); 

        aroot.setTop(getTop(stage));
        aroot.setCenter(getCenter(stage));
        aroot.setBottom(getBottom(stage));

        int height = 500;
        int width  = 600;

        Scene scene = new Scene(aroot, width, height);          

        stage.setTitle("State Pattern Demo Program - David A. Freitag - Version 1.0");
        stage.setScene(scene);
        scene.getStylesheets().add(AppTitleScreenState.class.getResource("application.css").toExternalForm());
        stage.show();
    }

    private VBox getTop(Stage stage) {
        VBox vbox = new VBox(10);
        vbox.setPadding(new Insets(20, 0, 0, 0));
        vbox.setAlignment(Pos.CENTER);

        Label blankLineT1 = new Label("Title Screen State");
        blankLineT1.setFont(Font.font("Helvetica", FontWeight.BOLD, 18));
        vbox.getChildren().addAll( blankLineT1);

        return vbox;
    }
    private VBox getCenter(Stage stage) {
        VBox vbox = new VBox(10);
        vbox.setPadding(new Insets(0, 0, 0, 0));
        vbox.setAlignment(Pos.CENTER);

        //----------------------------------------------------------------------
        DropShadow ds = new DropShadow();
        ds.setOffsetY(3.0f);
        ds.setColor(Color.color(0.4f, 0.4f, 0.4f));

        Text ee = new Text();
        ee.setEffect(ds);
        ee.setCache(true);
        ee.setX(10.0f);
        ee.setY(270.0f);
        ee.setFill(Color.BLUE);

        ee.setText("State Pattern Demo Program");
        ee.setFont(Font.font(null, FontWeight.NORMAL, 30));

        vbox.getChildren().addAll(ee); 

        //----------------------------------------------------------------------
        VBox vboxFiction = new VBox(0);
        vboxFiction.setAlignment(Pos.CENTER);
                
        Label LabelText1 = new Label("This is a demonstration program showing how 2 nested\n"
            + "State Patterns could be used with JavaFX."
            );
        Label labelText2 = new Label(
              "\nApp Controller"
            + "\n   ---> App Machine (green color)"
            + "\n            ---> Title Screen State"
            + "\n            ---> Information State"
            + "\n            ---> Game Machine (blue color)"
            + "\n                     ---> Game Play State"
            + "\n                     ---> Victory State"                
            + "\n                     ---> Defeat State"                
            );

        LabelText1.setFont(Font.font("Helvetica", FontWeight.NORMAL, 18));
        labelText2.setFont(Font.font("Helvetica", FontWeight.NORMAL, 18));

        vboxFiction.getChildren().addAll(LabelText1, labelText2);
        vbox.getChildren().addAll(vboxFiction);

        return vbox;
    }

    private HBox getBottom(Stage stage) {
        HBox hbox = new HBox(10);
        hbox.setPadding(new Insets(30, 10, 30, 10));
        hbox.setAlignment(Pos.CENTER);
        
        Button btPlay = new Button("  Play  ");
        hbox.getChildren().addAll(btPlay);

        Button btCopyright = new Button(" Information ");
        hbox.getChildren().addAll(btCopyright);

        btPlay.setOnMouseClicked(e -> {
            displayGameScreen(stage);
        });

        btCopyright.setOnMouseClicked(e -> {
            displayInformationScreen(stage);
        });

        return hbox;
    }
    
    public void displayTitleScreen(Stage stage) {
            System.out.println("Already in the Splash Screen");
    }

    public void displayInformationScreen(Stage stage) {
            appMachine.setState(appMachine.getAppCopyrightState()); 
            appMachine.start(stage);
    }

    public void displayGameScreen(Stage stage) {
            appMachine.setState(appMachine.getAppGameState()); 
            appMachine.start(stage);
    }
}