package com.dafreitag.game.states;

import com.dafreitag.app.machine.GameState;
import com.dafreitag.app.machine.AppController;
import com.dafreitag.app.machine.AppMachine;
import com.dafreitag.game.machine.GameMachine;
import javafx.application.Application;
import javafx.geometry.Insets;
import javafx.geometry.Pos;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.HBox;
import javafx.scene.layout.VBox;
import javafx.scene.text.Font;
import javafx.scene.text.FontWeight;
import javafx.stage.Stage;

public class GamePlayState extends Application implements GameState {
    GameMachine gameMachine;
	
    public GamePlayState(GameMachine gameMachine) {
	this.gameMachine = gameMachine;
    }
	
    @Override // Override the start method in the Application class
    public void start(Stage stage) {
    	BorderPane aroot = new BorderPane(); 
        aroot.setStyle("-fx-background-color: lightBlue");
        
        aroot.setTop(getTop(stage));
        aroot.setCenter(getCenter(stage));
        aroot.setBottom(getBottom(stage));
        
        int height = 500;
        int width = 600;

        Scene scene = new Scene(aroot, width, height);    
        
        stage.setTitle("State Pattern Demo Program - David A. Freitag - Version 1.0");
        
        stage.setScene(scene);
        scene.getStylesheets().add(GamePlayState.class.getResource("application.css").toExternalForm());
        stage.show();   
    }
  	
    private VBox getTop(Stage stage) {
        VBox vbox = new VBox(10);
        vbox.setPadding(new Insets(20, 0, 20, 0));
        vbox.setAlignment(Pos.CENTER);

        Label labelText = new Label("Game Play State");
        labelText.setFont(Font.font("Helvetica", FontWeight.BOLD, 18));
        vbox.getChildren().addAll(labelText);

        return vbox;
    }
    
    private VBox getCenter(Stage stage) {
        VBox vbox = new VBox(10);
        vbox.setPadding(new Insets(0, 0, 0, 0));
        vbox.setAlignment(Pos.CENTER);

        Label labelText = new Label("App Controller"
            + "\n  ---> App Machine"
            + "\n      ---> Game Machine"
            + "\n         ---> Game Play State"
            + "\n\nVictory goes to the Victory State under the Game Machine"
            + "\n\nDefeat goes to the Defeat State under the Game Machine"
            );
        labelText.setFont(Font.font("Helvetica", FontWeight.NORMAL, 18));
        vbox.getChildren().addAll(labelText);

        return vbox;
    }
 
    private HBox getBottom(Stage stage) {
        HBox hbox = new HBox(10);
        hbox.setPadding(new Insets(30, 10, 30, 10));
        hbox.setAlignment(Pos.CENTER);

        Button btVictory = new Button(" Victory ");
        hbox.getChildren().add(btVictory);

        Button btDefeat = new Button("  Defeat  ");
        hbox.getChildren().add(btDefeat);

        btVictory.setOnMouseClicked(e -> {
                victory(stage);
        });

        btDefeat.setOnMouseClicked(e -> {
                defeat(stage);
        });

        return hbox;
    }
 
    public void play(Stage stage) {
        gameMachine.setState(gameMachine.getGamePlayState()); 
        gameMachine.start(stage);
    }

    public void victory(Stage stage) {
        gameMachine.setState(gameMachine.getGameVictoryState()); 
        gameMachine.start(stage);
    }
    
    public void defeat(Stage stage) {
        gameMachine.setState(gameMachine.getGameDefeatState()); 
        gameMachine.start(stage);
    }
}